@@ -26,17 +26,19 @@ class VispParameters(ParameterBase):
     @property
     def background_num_spatial_bins(self) -> int:
         """Return number of spatial bins to use when computing background light."""
-        return self._find_most_recent_past_value("visp_background_num_spatial_bins")
+        return self._find_parameter_closest_wavelength("visp_background_num_spatial_bins")
 
     @property
     def background_wavelength_subsample_factor(self) -> int:
         """Return the sub-sampling factor used to reduce the number of wavelength samples."""
-        return self._find_most_recent_past_value("visp_background_wavelength_subsample_factor")
+        return self._find_parameter_closest_wavelength(
+            "visp_background_wavelength_subsample_factor"
+        )
 
     @property
     def background_num_fit_iterations(self) -> int:
         """Maximum number of fit iterations used to fit the background light."""
-        return self._find_most_recent_past_value("visp_background_num_fit_iterations")
+        return self._find_parameter_closest_wavelength("visp_background_num_fit_iterations")
 
     @property
     def background_continuum_index(self) -> list:
