@@ -1,7 +1,6 @@
 """Helper for ViSP array corrections."""
 from typing import Generator
 from typing import Iterable
-from typing import Union
 
 import numpy as np
 import scipy.ndimage as spnd
@@ -14,7 +13,7 @@ class CorrectionsMixin:
 
     @staticmethod
     def corrections_correct_geometry(
-        arrays: Union[Iterable[np.ndarray], np.ndarray],
+        arrays: Iterable[np.ndarray] | np.ndarray,
         shift: np.ndarray = np.zeros(2),
         angle: float = 0.0,
     ) -> Generator[np.ndarray, None, None]:
@@ -33,7 +32,7 @@ class CorrectionsMixin:
             so a single wavelength is at the same pixel for all slit positions.
 
         angle : float
-            The angle between slit hairlines and pixel axes.
+            The angle (in radians) between slit hairlines and pixel axes.
 
         Returns
         -------
@@ -42,21 +41,16 @@ class CorrectionsMixin:
         """
         arrays = [arrays] if isinstance(arrays, np.ndarray) else arrays
         for array in arrays:
+            array = array.astype(np.float64)
             array[np.where(array == np.inf)] = np.max(array[np.isfinite(array)])
             array[np.where(array == -np.inf)] = np.min(array[np.isfinite(array)])
             array[np.isnan(array)] = np.nanmedian(array)
-            translated = affine_transform_arrays(
-                array, translation=-shift, mode="constant", cval=np.nanmedian(array)
-            )
-            yield next(
-                rotate_arrays_about_point(
-                    translated, angle=-angle, mode="constant", cval=np.nanmedian(array)
-                )
-            )
+            translated = affine_transform_arrays(array, translation=-shift, mode="reflect", order=5)
+            yield next(rotate_arrays_about_point(translated, angle=-angle, mode="reflect", order=5))
 
     @staticmethod
     def corrections_remove_spec_geometry(
-        arrays: Union[Iterable[np.ndarray], np.ndarray], spec_shift: np.ndarray
+        arrays: Iterable[np.ndarray] | np.ndarray, spec_shift: np.ndarray
     ) -> Generator[np.ndarray, None, None]:
         """
         Remove spectral curvature.
