@@ -2,9 +2,7 @@
 import logging
 from typing import Generator
 from typing import Iterable
-from typing import Optional
 from typing import TypeVar
-from typing import Union
 
 import numpy as np
 from astropy.io import fits
@@ -21,10 +19,10 @@ class IntermediateFrameHelpersMixin:
 
     def intermediate_frame_helpers_load_intermediate_arrays(
         self,
-        beam: Optional[int] = None,
-        task: Optional[str] = None,
-        modstate: Optional[int] = None,
-        exposure_time: Optional[float] = None,
+        beam: int | None = None,
+        task: str | None = None,
+        modstate: int | None = None,
+        exposure_time: float | None = None,
     ) -> Generator[np.ndarray, None, None]:
         """
         Yield a generator that produces ndarrays for the requested tags.
@@ -58,7 +56,7 @@ class IntermediateFrameHelpersMixin:
             yield hdu.data
 
     def intermediate_frame_helpers_load_dark_array(
-        self, beam: Optional[int] = None, exposure_time: Optional[float] = None
+        self, beam: int | None = None, exposure_time: float | None = None
     ) -> np.ndarray:
         """
         Produce dark ndarrays for the requested tags.
@@ -82,8 +80,29 @@ class IntermediateFrameHelpersMixin:
             )
         )
 
+    def intermediate_frame_helpers_load_background_array(
+        self,
+        beam: int | None = None,
+    ) -> np.ndarray:
+        """
+        Produce background light ndarrays for the requested tags.
+
+        Parameters
+        ----------
+        beam : int
+            The current beam being processed
+
+        Returns
+        -------
+        ndarray
+            Array of loaded intermediate background light data with requested tags
+        """
+        return next(
+            self.intermediate_frame_helpers_load_intermediate_arrays(beam=beam, task="BACKGROUND")
+        )
+
     def intermediate_frame_helpers_load_lamp_gain_array(
-        self, beam: Optional[int] = None, modstate: Optional[int] = None
+        self, beam: int | None = None, modstate: int | None = None
     ) -> np.ndarray:
         """
         Produce lamp gain ndarrays for the requested tags.
@@ -108,7 +127,7 @@ class IntermediateFrameHelpersMixin:
         )
 
     def intermediate_frame_helpers_load_solar_gain_array(
-        self, beam: Optional[int] = None, modstate: Optional[int] = None
+        self, beam: int | None = None, modstate: int | None = None
     ) -> np.ndarray:
         """
         Produce solar gain ndarrays for the requested tags.
@@ -133,7 +152,7 @@ class IntermediateFrameHelpersMixin:
         )
 
     def intermediate_frame_helpers_load_demodulated_arrays(
-        self, beam: Optional[int] = None, modstate: Optional[int] = None
+        self, beam: int | None = None, modstate: int | None = None
     ) -> Generator[np.ndarray, None, None]:
         """
         Produce demodulated arrays for the requested tags.
@@ -157,15 +176,15 @@ class IntermediateFrameHelpersMixin:
 
     def intermediate_frame_helpers_write_arrays(
         self,
-        arrays: Union[Iterable[np.ndarray], np.ndarray],
-        headers: Optional[Union[Iterable[fits.Header], fits.Header]] = None,
-        beam: Optional[int] = None,
-        modstate: Optional[int] = None,
-        map_scan: Optional[int] = None,
-        raster_step: Optional[int] = None,
-        task: Optional[str] = None,
-        exposure_time: Optional[float] = None,
-        file_id: Optional[str] = None,
+        arrays: Iterable[np.ndarray] | np.ndarray,
+        headers: Iterable[fits.Header] | fits.Header | None = None,
+        beam: int | None = None,
+        modstate: int | None = None,
+        map_scan: int | None = None,
+        raster_step: int | None = None,
+        task: str | None = None,
+        exposure_time: float | None = None,
+        file_id: str | None = None,
     ) -> None:
         """
         Write out intermediate files with requested tags.
