@@ -342,9 +342,13 @@ class WavelengthParameter:
 @dataclass
 class VispTestingParameters:
     visp_beam_border: int = 1000
-    visp_background_num_spatial_bins: int = 1
-    visp_background_wavelength_subsample_factor: int = 10
-    visp_background_num_fit_iterations: int = 20
+    visp_background_num_spatial_bins: WavelengthParameter = WavelengthParameter(values=(1, 4, 1, 1))
+    visp_background_wavelength_subsample_factor: WavelengthParameter = WavelengthParameter(
+        values=(10, 7, 10, 10)
+    )
+    visp_background_num_fit_iterations: WavelengthParameter = WavelengthParameter(
+        values=(20, 100, 20, 20)
+    )
     visp_background_continuum_index: WavelengthParameter = WavelengthParameter(
         values=(list(range(190)), list(range(190)), list(range(190)), list(range(190)))
     )
